netapp_ontap.resources.s3_service API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.s3_service`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

An S3 server is an object store server that is compatible with the Amazon S3 protocol. In the initial version, only a subset of the protocol features necessary to support Fabric Pool capacity tier usecases are implemented. S3 server allows you to store objects in ONTAP using Amazon S3 protocol. This feature can be used as a target object store server for ONTAP FabricPools.

## Performance monitoring

Performance of the SVM can be monitored by the `metric.*` and `statistics.*` properties. These show the performance of the SVM in terms of IOPS, latency and throughput. The `metric.*` properties denote an average whereas `statistics.*` properties denote a real-time monotonically increasing value aggregated across all nodes.

## Examples

### Retrieving all of the S3 configurations

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import S3Service

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(S3Service.get_collection(fields="*", return_timeout=15)))

Try it out

    [
        S3Service(
            {
                "enabled": False,
                "comment": "S3 server",
                "svm": {"name": "vs2", "uuid": "cf90b8f2-8071-11e9-8190-0050568eae21"},
                "name": "s1",
            }
        ),
        S3Service(
            {
                "buckets": [
                    {
                        "uuid": "e08665af-8114-11e9-8190-0050568eae21",
                        "volume": {
                            "name": "fg_oss_1559026220",
                            "uuid": "de146bff-8114-11e9-8190-0050568eae21",
                        },
                        "comment": "s3 bucket",
                        "name": "bucket-1",
                        "size": 209715200,
                        "logical_used_size": 157286400,
                        "encryption": {"enabled": False},
                    },
                    {
                        "uuid": "fb1912ef-8114-11e9-8190-0050568eae21",
                        "volume": {
                            "name": "fg_oss_1559026269",
                            "uuid": "f9b1cdd0-8114-11e9-8190-0050568eae21",
                        },
                        "comment": "s3 bucket",
                        "name": "bucket-2",
                        "size": 104857600,
                        "logical_used_size": 78643200,
                        "encryption": {"enabled": False},
                    },
                ],
                "enabled": True,
                "users": [
                    {
                        "access_key": "3333_w162ypaTi7_aAQuJo76Z16zc9Gz_W3IN83bDQWkcCN3jYU_z_xn20XATMKKa90509KCH__r4lh1IPU58vf1QlWAJt8k2F1BPjPtM6CsDRX_dOP_QZkF5N9fBuz3",
                        "comment": "S3 user",
                        "name": "user-1",
                    },
                    {
                        "access_key": "g6T24qhH92dOA6gc1WTcDO_2oNZhQ6Drl2zu5_s5Id_QK1wLgghgxsD2xP1xqG7oX1T_9AI0D39q65CY3FAg0CbAtVU_903bSnCnht3xqjbrF5_3Cs9RnY8nE_az1Ltc",
                        "comment": "",
                        "name": "user-2",
                    },
                ],
                "comment": "S3 server",
                "svm": {"name": "vs1", "uuid": "d7f1219c-7f8e-11e9-9124-0050568eae21"},
                "name": "Server-1",
            }
        ),
    ]

### Retrieving all S3 configurations for a particular SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import S3Service

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = S3Service(**{"svm.uuid": "24c2567a-f269-11e8-8852-0050568e5298"})
        resource.get(fields="*")
        print(resource)

Try it out

    S3Service(
        {
            "buckets": [
                {
                    "uuid": "e08665af-8114-11e9-8190-0050568eae21",
                    "volume": {
                        "name": "fg_oss_1559026220",
                        "uuid": "de146bff-8114-11e9-8190-0050568eae21",
                    },
                    "comment": "s3 bucket",
                    "name": "bucket-1",
                    "policy": {
                        "statements": [
                            {
                                "sid": "DenyAccessToGetPutDeleteObjectForMike",
                                "effect": "deny",
                                "principals": ["mike"],
                                "actions": ["*Object"],
                                "resources": [
                                    "bucket-1/policy-docs/*",
                                    "bucket-1/confidential-*",
                                ],
                            },
                            {
                                "sid": "AccessToGetObjectForAnonymousUser",
                                "effect": "allow",
                                "principals": ["*"],
                                "actions": ["GetObject"],
                                "resources": ["bucket-1/readme"],
                            },
                        ]
                    },
                    "size": 209715200,
                    "logical_used_size": 157286400,
                    "encryption": {"enabled": False},
                },
                {
                    "uuid": "fb1912ef-8114-11e9-8190-0050568eae21",
                    "volume": {
                        "name": "fg_oss_1559026269",
                        "uuid": "f9b1cdd0-8114-11e9-8190-0050568eae21",
                    },
                    "comment": "s3 bucket",
                    "name": "bucket-2",
                    "size": 1677721600,
                    "logical_used_size": 1075838976,
                    "encryption": {"enabled": False},
                },
            ],
            "enabled": True,
            "users": [
                {
                    "access_key": "3333_w162ypaTi7_aAQuJo76Z16zc9Gz_W3IN83bDQWkcCN3jYU_z_xn20XATMKKa90509KCH__r4lh1IPU58vf1QlWAJt8k2F1BPjPtM6CsDRX_dOP_QZkF5N9fBuz3",
                    "comment": "s3 user",
                    "name": "user-1",
                },
                {
                    "access_key": "g6T24qhH92dOA6gc1WTcDO_2oNZhQ6Drl2zu5_s5Id_QK1wLgghgxsD2xP1xqG7oX1T_9AI0D39q65CY3FAg0CbAtVU_903bSnCnht3xqjbrF5_3Cs9RnY8nE_az1Ltc",
                    "comment": "",
                    "name": "user-2",
                },
            ],
            "comment": "S3 server",
            "svm": {"name": "vs1", "uuid": "d7f1219c-7f8e-11e9-9124-0050568eae21"},
            "name": "Server-1",
        }
    )

### Creating an S3 server, users, and buckets configurations with required fields specified

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import S3Service

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = S3Service()
        resource.buckets = [{"name": "bucket-1"}, {"name": "bucket-2"}]
        resource.enabled = True
        resource.name = "Server-1"
        resource.svm.uuid = "d49ef663-7f8e-11e9-9b2c-0050568e4594"
        resource.users = [{"name": "user-1"}, {"name": "user-2"}]
        resource.post(hydrate=True)
        print(resource)

Try it out

    S3Service(
        {
            "users": [
                {
                    "access_key": "x129aL0q9bu3J_4_2S0OcU34AA5DJXXB_j9R34_60tqiqAS5_c8PAgN6Lg1zkv_76P4IxNWir9st9uhhgldb31u364Cczq_c39C1fUP7HDheUmYY6u4xt61_N7Sw6c33",
                    "name": "user-1",
                },
                {
                    "access_key": "nntYZrNN65mKn57yS04o1sDp_D0AY58jdwCW573_5x2OPW09AbyFl86DB7r30N2373_bA12n08aovQp8ySItRss9AjsYoSj7TsIiHOW_Y21DaqYPl5I2a849b11y8X4c",
                    "name": "user-2",
                },
            ],
            "_links": {"self": {"href": "/api/protocols/s3/services/"}},
        }
    )

### Creating an S3 server, users, and buckets configurations

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import S3Service

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = S3Service()
        resource.buckets = [
            {
                "aggregates": [
                    {"name": "aggr1", "uuid": "1cd8a442-86d1-11e0-ae1c-123478563412"}
                ],
                "constituents_per_aggregate": 4,
                "name": "bucket-1",
                "size": "209715200",
                "policy": {
                    "statements": [
                        {
                            "actions": ["*"],
                            "conditions": [
                                {
                                    "operator": "ip_address",
                                    "source_ips": ["1.1.1.1/23", "1.2.2.2/20"],
                                }
                            ],
                            "effect": "allow",
                            "resources": ["bucket-1", "bucket-1*"],
                            "sid": "fullAccessForAllPrincipalsToBucket",
                        }
                    ]
                },
            },
            {
                "aggregates": [
                    {"name": "aggr1", "uuid": "1cd8a442-86d1-11e0-ae1c-123478563412"},
                    {"name": "aggr2", "uuid": "982fc4d0-d1a2-4da4-9c47-5b433f24757d"},
                ],
                "constituents_per_aggregate": 4,
                "name": "bucket-2",
            },
        ]
        resource.enabled = True
        resource.name = "Server-1"
        resource.svm.name = "vs1"
        resource.svm.uuid = "d49ef663-7f8e-11e9-9b2c-0050568e4594"
        resource.users = [{"name": "user-1"}, {"name": "user-2"}]
        resource.post(hydrate=True)
        print(resource)

Try it out

    S3Service(
        {
            "users": [
                {
                    "access_key": "x129aL0q9bu3J_4_2S0OcU34AA5DJXXB_j9R34_60tqiqAS5_c8PAgN6Lg1zkv_76P4IxNWir9st9uhhgldb31u364Cczq_c39C1fUP7HDheUmYY6u4xt61_N7Sw6c33",
                    "name": "user-1",
                },
                {
                    "access_key": "nntYZrNN65mKn57yS04o1sDp_D0AY58jdwCW573_5x2OPW09AbyFl86DB7r30N2373_bA12n08aovQp8ySItRss9AjsYoSj7TsIiHOW_Y21DaqYPl5I2a849b11y8X4c",
                    "name": "user-2",
                },
            ],
            "_links": {"self": {"href": "/api/protocols/s3/services/"}},
        }
    )

### Creating an S3 server configuration

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import S3Service

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = S3Service()
        resource.comment = "S3 server"
        resource.enabled = True
        resource.name = "Server-1"
        resource.svm.name = "vs1"
        resource.svm.uuid = "db2ec036-8375-11e9-99e1-0050568e3ed9"
        resource.post(hydrate=True)
        print(resource)

### Disable s3 server for the specified SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import S3Service

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = S3Service(**{"svm.uuid": "03ce5c36-f269-11e8-8852-0050568e5298"})
        resource.enabled = False
        resource.patch()

### Deleting the S3 server for a specified SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import S3Service

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = S3Service(**{"svm.uuid": "a425f10b-ad3b-11e9-b559-0050568e8222"})
        resource.delete(delete_all=False)

### Deleting all of the S3 server configuration for a specified SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import S3Service

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = S3Service(**{"svm.uuid": "03ce5c36-f269-11e8-8852-0050568e5298"})
        resource.delete(delete_all=True)

## Classes

`class S3Service (*args, **kwargs)`

  Specifies the S3 server configuration.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves the S3 server configuration for all SVMs. Note that in order to retrieve S3 bucket policy conditions, 'fields' option should be set to '**'.

    ### Expensive properties

    There is an added cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more. * `statistics.*` * `metric.*`

    ### Related ONTAP commands

    - `vserver object-store-server show`

    ### Learn more

    - `DOC /protocols/s3/services`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection(*args, body: typing.Union = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes the S3 server configuration of an SVM. If the 'delete_all' parameter is set to false, only the S3 server is deleted. Otherwise S3 users and buckets present on the SVM are also deleted. Note that only empty buckets can be deleted. This endpoint returns the S3 server delete job-uuid in response. To monitor the job status follow /api/cluster/jobs/.

    ### Related ONTAP commands

    - `vserver object-store-server delete`

    ### Learn more

    - `DOC /protocols/s3/services`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves the S3 server configuration for all SVMs. Note that in order to retrieve S3 bucket policy conditions, 'fields' option should be set to '**'.

    ### Expensive properties

    There is an added cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more. * `statistics.*` * `metric.*`

    ### Related ONTAP commands

    - `vserver object-store-server show`

    ### Learn more

    - `DOC /protocols/s3/services`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves the S3 server configuration for all SVMs. Note that in order to retrieve S3 bucket policy conditions, 'fields' option should be set to '**'.

    ### Expensive properties

    There is an added cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more. * `statistics.*` * `metric.*`

    ### Related ONTAP commands

    - `vserver object-store-server show`

    ### Learn more

    - `DOC /protocols/s3/services`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection(body: dict, *args, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates the S3 Server configuration of an SVM.

    ### Related ONTAP commands

    - `vserver object-store-server modify`

    ### Learn more

    - `DOC /protocols/s3/services`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Deletes the S3 server configuration of an SVM. If the 'delete_all' parameter is set to false, only the S3 server is deleted. Otherwise S3 users and buckets present on the SVM are also deleted. Note that only empty buckets can be deleted. This endpoint returns the S3 server delete job-uuid in response. To monitor the job status follow /api/cluster/jobs/.

    ### Related ONTAP commands

    - `vserver object-store-server delete`

    ### Learn more

    - `DOC /protocols/s3/services`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves the S3 Server configuration of an SVM. Note that in order to retrieve S3 bucket policy conditions, the 'fields' option should be set to '**'.

    ### Related ONTAP commands

    - `vserver object-store-server show`

    ### Learn more

    - `DOC /protocols/s3/services`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates the S3 Server configuration of an SVM.

    ### Related ONTAP commands

    - `vserver object-store-server modify`

    ### Learn more

    - `DOC /protocols/s3/services`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Creates an S3 server, users, and buckets configurations.

    ### Important notes

    - Each SVM can have one S3 server configuration.
    - One or more buckets and users can also be created using this end-point.
    - If creating a user configuration fails, buckets are not created either and already created users are not saved.
    - If creating a bucket configuration fails, all buckets already created are saved with no new buckets created.

    ### Required properties

    - `svm.uuid` - Existing SVM in which to create an S3 server configuration.

    ### Recommended optional properties

    - `enabled` - Specifies the state of the server created.
    - `comment` - Any information related to the server created.

    ### Default property values

    - `comment` - ""
    - `enabled` - true

    ### Related ONTAP commands

    - `vserver object-store-server create`
    - `vserver object-store-server bucket create`
    - `vserver object-store-server bucket policy statement create`
    - `vserver object-store-server bucket policy-statement-condition create`
    - `vserver object-store-server user create`

    ### Learn more

    - `DOC /protocols/s3/services`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class S3ServiceSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the S3Service object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `buckets GET POST`

    The buckets field of the s3_service.

  `certificate GET POST PATCH`

    The certificate field of the s3_service.

  `comment GET POST PATCH`

    Can contain any additional information about the server being created or modified.

    Example: S3 server

  `enabled GET POST PATCH`

    Specifies whether the S3 server being created or modified should be up or down.

  `is_http_enabled GET POST PATCH`

    Specifies whether HTTP is enabled on the S3 server being created or modified. By default, HTTP is disabled on the S3 server.

  `is_https_enabled GET POST PATCH`

    Specifies whether HTTPS is enabled on the S3 server being created or modified. By default, HTTPS is enabled on the S3 server.

  `links GET`

    The links field of the s3_service.

  `metric GET`

    The metric field of the s3_service.

  `name GET POST PATCH`

    Specifies the name of the S3 server. A server name can contain 1 to 253 characters using only the following combination of characters':' 0-9, A-Z, a-z, ".", and "-".

    Example: Server-1

  `port GET POST PATCH`

    Specifies the HTTP listener port for the S3 server. By default, HTTP is enabled on port 80.

  `secure_port GET POST PATCH`

    Specifies the HTTPS listener port for the S3 server. By default, HTTPS is enabled on port 443.

  `statistics GET`

    The statistics field of the s3_service.

  `svm GET POST`

    The svm field of the s3_service.

  `users GET POST`

    The users field of the s3_service.